@@ -31,16 +31,9 @@
 #  This code is licensed under the GNU General Public License v2.
 #  Full text may be retrieved at http://www.gnu.org/licenses/gpl-2.0.txt
 # ---------------------------------------------------------------------------
-import sys
+from ..GXIntEnum import GXIntEnum
 
-#pylint: disable=no-name-in-module
-if sys.version_info < (3, 0):
-    __base = object
-else:
-    from enum import IntEnum
-    __base = IntEnum
-
-class ErrorCode(__base):
+class ErrorCode(GXIntEnum):
     """Enumerates all DLMS error codes.
     https://www.gurux.fi/Gurux.DLMS.ErrorCodes
     """
