@@ -126,6 +126,12 @@ class GXDLMSActivityCalendar(GXDLMSObject, IGXDLMSBase):
     def getAttributeCount(self):
         return 10
 
+    #
+    # This method copies all passive properties to the active.
+    #
+    def activatePassiveCalendar(self, client):
+        return client.method(self, 1, int(0), DataType.INT8)
+
     #
     # Returns amount of methods.
     #
