@@ -69,6 +69,66 @@ class GXDLMSMBusClient(GXDLMSObject, IGXDLMSBase):
         self.encryptionKeyStatus = MBusEncryptionKeyStatus.NO_ENCRYPTION_KEY
         self.version = 1
 
+    def slaveInstall(self, client):
+        """Installs a slave device."""
+        return client.method(self.getName(), self.objectType, 1, 0, DataType.INT8)
+
+    def slaveDeInstall(self, client):
+        """De-installs a slave device."""
+        return client.method(self.getName(), self.objectType, 2, 0, DataType.INT8)
+
+    def capture(self, client):
+        """Captures values."""
+        return client.method(self.getName(), self.objectType, 3, 0, DataType.INT8)
+
+    def resetAlarm(self, client):
+        """Resets alarm state of the M-Bus slave device."""
+        return client.method(self.getName(), self.objectType, 4, 0, DataType.INT8)
+
+    def synchronizeClock(self, client):
+        """Synchronize the clock."""
+        return client.method(self.getName(), self.objectType, 5, 0, DataType.INT8)
+
+    def sendData(self, client, data):
+        """Sends data to the M-Bus slave device."""
+        bb = GXByteBuffer()
+        bb.setUInt8(DataType.ARRAY)
+        bb.setUInt8(DataType.STRUCTURE)
+        _GXCommon.setObjectCount(len(data), bb)
+        for it in data:
+            bb.setUInt8(DataType.STRUCTURE)
+            bb.setUInt8(3)
+            bb.setUInt8(DataType.OCTET_STRING)
+            _GXCommon.setObjectCount(it.DataInformation.Length, bb)
+            bb.set(it.DataInformation)
+            bb.setUInt8(DataType.OCTET_STRING)
+            _GXCommon.setObjectCount(it.ValueInformation.Length, bb)
+            bb.set(it.ValueInformation)
+            _GXCommon.setData(None, bb, _GXCommon.getDLMSDataType(it.Data), it.Data)
+        return client.method(self.getName(), self.objectType, 6, bb, DataType.ARRAY)
+
+    def setEncryptionKey(self, client, encryptionKey):
+        """Sets the encryption key in the M-Bus client and enables encrypted communication with the M-Bus slave device."""
+        bb = GXByteBuffer()
+        bb.setUInt8(DataType.OCTET_STRING)
+        if not encryptionKey:
+            bb.setUInt8(0)
+        else:
+            _GXCommon.setObjectCount(encryptionKey.Length, bb)
+            bb.set(encryptionKey)
+        return client.method(self.getName(), self.objectType, 7, bb, DataType.ARRAY)
+
+    def transferKey(self, client, encryptionKey):
+        """Transfers an encryption key to the M-Bus slave device."""
+        bb = GXByteBuffer()
+        bb.setUInt8(DataType.OCTET_STRING)
+        if not encryptionKey:
+            bb.setUInt8(0)
+        else:
+            _GXCommon.setObjectCount(encryptionKey.Length, bb)
+            bb.set(encryptionKey)
+        return client.method(self.getName(), self.objectType, 8, bb, DataType.ARRAY)
+
     def getValues(self):
         if self.version == 0:
             return [self.logicalName,
